Documentation
¶
Overview ¶
Package doctor runs automated diagnostics on the development stack.
Index ¶
- func PrintFindings(w io.Writer, findings []Finding)
- type CheckFunc
- type Doctor
- type Finding
- func CheckContainerStatus(ctx context.Context, opts *Options) []Finding
- func CheckCrashLoops(ctx context.Context, opts *Options) []Finding
- func CheckEnvDrift(ctx context.Context, opts *Options) []Finding
- func CheckLocalhostMisuse(ctx context.Context, opts *Options) []Finding
- func CheckPortConflicts(ctx context.Context, opts *Options) []Finding
- type Options
- type Severity
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func PrintFindings ¶
PrintFindings formats findings for terminal output with color support.
Types ¶
type Doctor ¶
type Doctor struct {
// contains filtered or unexported fields
}
Doctor orchestrates diagnostic checks.
type Finding ¶
Finding represents a single diagnostic result.
func CheckContainerStatus ¶
CheckContainerStatus reports running containers as OK findings.
func CheckCrashLoops ¶
CheckCrashLoops detects services stuck in restarting or exited state.
func CheckEnvDrift ¶
CheckEnvDrift detects keys present in .env.example but missing from .env.
func CheckLocalhostMisuse ¶
CheckLocalhostMisuse warns when .env contains localhost references that should use Docker service names inside containers.
Click to show internal directories.
Click to hide internal directories.